@@ -77,6 +77,8 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         df_logs_combined['Date'] = df_logs_combined['Local_Timestamp'].dt.date
     except IndexError:
         raise Exception("IndexError: list index out of range (battery_level) : " + intermediate_participant_path + sep + date_in_study + str(list(df_logs_combined["Local_Time"])))
+    except Exception:
+        raise Exception("Exception (battery_level) : " + intermediate_participant_path + sep + date_in_study)
 
     return df_logs_combined
 
