@@ -143,7 +143,7 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     try:
         df_raw = pd.read_csv(csv_path[0])
     except pandas.errors.EmptyDataError:
-        raise Exception("pandas.errors.EmptyDataError  : " + csv_path[0])
+        raise Exception("pandas.errors.EmptyDataError (prompt response) : " + csv_path[0])
 
 
     if df_raw.shape[0] == 0:
