@@ -59,7 +59,10 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         csv_path_list = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
 
         csv_path = csv_path_list[0]
-        df_day = pd.read_csv(csv_path)
+        try:
+            df_day = pd.read_csv(csv_path[0])
+        except pd.errors.EmptyDataError:
+            raise Exception("pandas.errors.EmptyDataError (screen_status) : " + csv_path[0])
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
             df_logs_combined = pd.concat([df_logs_combined, df_day])
@@ -75,7 +78,8 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
                                          list(df_logs_combined["LOG_TIME"])]
 
     df_logs_combined['LOG_TIME_DATETIME'] = pd.Series(map(converter, df_logs_combined["LOG_TIME"]))
-    df_logs_combined['Date'] = df_logs_combined['LOG_TIME_DATETIME'].dt.date
+    if df_logs_combined.shape[0] > 0:
+        df_logs_combined['Date'] = df_logs_combined['LOG_TIME_DATETIME'].dt.date
 
     return df_logs_combined
 
